==> haskell-selective-0.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: selective
version: 0.3
id: selective-0.3-9MMCZl8FVw9LdEN0QDP4dI
key: selective-0.3-9MMCZl8FVw9LdEN0QDP4dI
license: MIT
copyright: Andrey Mokhov, 2018-2019
maintainer: Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard
author: Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard
stability: experimental
homepage: https://github.com/snowleopard/selective
synopsis: Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.
    .
    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://www.staff.ncl.ac.uk/andrey.mokhov/selective-functors.pdf this paper>.
category: Control
abi: dd41c59c79ce7ab62ee6a696db42c22d
exposed: True
exposed-modules:
    Control.Selective Control.Selective.Free
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
import-dirs: /usr/lib/ghc-8.6.5/site-local/selective-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/selective-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/selective-0.3
hs-libraries: HSselective-0.3-9MMCZl8FVw9LdEN0QDP4dI
depends:
    base-4.12.0.0 containers-0.6.0.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html: /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-selective-0.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: selective
version: 0.3
id: selective-0.3-K83RUWnyCj7HSr3MUQYrzZ
key: selective-0.3-K83RUWnyCj7HSr3MUQYrzZ
license: MIT
copyright: Andrey Mokhov, 2018-2019
maintainer: Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard
author: Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard
stability: experimental
homepage: https://github.com/snowleopard/selective
synopsis: Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.
    .
    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://www.staff.ncl.ac.uk/andrey.mokhov/selective-functors.pdf this paper>.
category: Control
abi: 9c7f8ee7c5ed43440905e315f27d3761
exposed: True
exposed-modules:
    Control.Selective Control.Selective.Free
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
import-dirs: /usr/lib/ghc-8.6.5/site-local/selective-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/selective-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/selective-0.3
hs-libraries: HSselective-0.3-K83RUWnyCj7HSr3MUQYrzZ
depends:
    base-4.12.0.0 containers-0.6.0.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html: /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
